# 🪄 chico-dico-magic

[![License](https://img.shields.io/github/license/luochang212/chico-dico-magic)](https://github.com/luochang212/chico-dico-magic)
[![PyPI](https://img.shields.io/pypi/v/chico-dico.svg?logo=python)](https://pypi.python.org/pypi/chico-dico-magic)
[![GitHub](https://img.shields.io/github/v/release/luochang212/chico-dico-magic?logo=github&sort=semver)](https://github.com/luochang212/chico-dico-magic)
[![CI](https://github.com/luochang212/chico-dico-magic/workflows/CI/badge.svg)](https://github.com/luochang212/chico-dico-magic/actions?query=workflow:CI)
[![Downloads](https://static.pepy.tech/personalized-badge/chico-dico?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/chico-dico)

Chico & Dico 的魔术
